@@ -506,7 +506,7 @@ city_uint128 CityHash128(const char *s, size_t len) {
 }
 
 #ifdef __SSE4_2__
-#include <citycrc.h>
+#include <city/citycrc.h>
 #include <nmmintrin.h>
 
 // Requires len >= 240.
